audformat.define
================

.. automodule:: audformat.define


DataType
---------

.. autoclass:: DataType
    :members:
    :undoc-members:

Gender
------

.. autoclass:: Gender
    :members:
    :undoc-members:

IndexField
----------

.. autoclass:: IndexField
    :members:
    :undoc-members:

IndexType
---------

.. autoclass:: IndexType
    :members:
    :undoc-members:

MediaType
---------

.. autoclass:: MediaType
    :members:
    :undoc-members:

RaterType
---------

.. autoclass:: RaterType
    :members:
    :undoc-members:

SplitType
---------

.. autoclass:: SplitType
    :members:
    :undoc-members:

TableStorageFormat
------------------

.. autoclass:: TableStorageFormat
    :members:
    :undoc-members:

Usage
-----

.. autoclass:: Usage
    :members:
    :undoc-members:
